@@ -1,13 +1,19 @@
+/*
+    SPDX-FileCopyrightText: 2022 Jean-Baptiste Mardelle <jb@kdenlive.org>
+    SPDX-FileCopyrightText: 2017-2019 Nicolas Carion <french.ebook.lover@gmail.com>
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
+#include "doc/kdenlivedoc.h"
 #include "test_utils.hpp"
 
-Mlt::Profile profile_composition;
-QString aCompo;
-TEST_CASE("Basic creation/deletion of a composition", "[CompositionModel]")
+static QString getACompo()
 {
+
     // Check whether repo works
     QVector<QPair<QString, QString>> transitions = TransitionsRepository::get()->getNames();
     REQUIRE(!transitions.isEmpty());
 
+    QString aCompo;
     // Look for a compo
     for (const auto &trans : qAsConst(transitions)) {
         if (TransitionsRepository::get()->isComposition(trans.first)) {
@@ -15,8 +21,13 @@ TEST_CASE("Basic creation/deletion of a composition", "[CompositionModel]")
             break;
         }
     }
-
     REQUIRE(!aCompo.isEmpty());
+    return aCompo;
+}
+
+TEST_CASE("Basic creation/deletion of a composition", "[CompositionModel]")
+{
+    QString aCompo = getACompo();
 
     // Check construction from repo
     std::unique_ptr<Mlt::Transition> mlt_transition(TransitionsRepository::get()->getTransition(aCompo));
@@ -24,8 +35,18 @@ TEST_CASE("Basic creation/deletion of a composition", "[CompositionModel]")
     REQUIRE(mlt_transition->is_valid());
 
     std::shared_ptr<DocUndoStack> undoStack = std::make_shared<DocUndoStack>(nullptr);
-    std::shared_ptr<MarkerListModel> guideModel(new MarkerListModel(undoStack));
-    std::shared_ptr<TimelineItemModel> timeline = TimelineItemModel::construct(&profile_composition, guideModel, undoStack);
+
+    KdenliveDoc document(undoStack);
+    Mock<KdenliveDoc> docMock(document);
+    When(Method(docMock, getCacheDir)).AlwaysReturn(QDir(QStandardPaths::writableLocation(QStandardPaths::CacheLocation)));
+    KdenliveDoc &mockedDoc = docMock.get();
+
+    pCore->projectManager()->m_project = &mockedDoc;
+    QDateTime documentDate = QDateTime::currentDateTime();
+    pCore->projectManager()->updateTimeline(0, false, QString(), QString(), documentDate, 0);
+    auto timeline = mockedDoc.getTimeline(mockedDoc.uuid());
+    pCore->projectManager()->m_activeTimelineModel = timeline;
+    pCore->projectManager()->testSetActiveDocument(&mockedDoc, timeline);
 
     REQUIRE(timeline->getCompositionsCount() == 0);
     int id1 = CompositionModel::construct(timeline, aCompo, QString());
@@ -44,20 +65,30 @@ TEST_CASE("Basic creation/deletion of a composition", "[CompositionModel]")
     REQUIRE(timeline->getCompositionsCount() == 1);
     REQUIRE(timeline->requestItemDeletion(id1));
     REQUIRE(timeline->getCompositionsCount() == 0);
+    pCore->projectItemModel()->clean();
 }
 
 TEST_CASE("Composition manipulation", "[CompositionModel]")
 {
     std::shared_ptr<DocUndoStack> undoStack = std::make_shared<DocUndoStack>(nullptr);
-    std::shared_ptr<MarkerListModel> guideModel(new MarkerListModel(undoStack));
-    std::shared_ptr<TimelineItemModel> timeline = TimelineItemModel::construct(&profile_composition, guideModel, undoStack);
+    KdenliveDoc document(undoStack, {0, 3});
+    Mock<KdenliveDoc> docMock(document);
+    When(Method(docMock, getCacheDir)).AlwaysReturn(QDir(QStandardPaths::writableLocation(QStandardPaths::CacheLocation)));
+    KdenliveDoc &mockedDoc = docMock.get();
 
-    int tid0 = TrackModel::construct(timeline);
-    Q_UNUSED(tid0);
-    int tid1 = TrackModel::construct(timeline);
+    pCore->projectManager()->m_project = &mockedDoc;
+    QDateTime documentDate = QDateTime::currentDateTime();
+    pCore->projectManager()->updateTimeline(0, false, QString(), QString(), documentDate, 0);
+    auto timeline = mockedDoc.getTimeline(mockedDoc.uuid());
+    pCore->projectManager()->m_activeTimelineModel = timeline;
+    pCore->projectManager()->testSetActiveDocument(&mockedDoc, timeline);
+
+    QString aCompo = getACompo();
+
+    int tid1 = timeline->getTrackIndexFromPosition(0);
+    int tid2 = timeline->getTrackIndexFromPosition(1);
+    int tid3 = timeline->getTrackIndexFromPosition(2);
     int cid2 = CompositionModel::construct(timeline, aCompo, QString());
-    int tid2 = TrackModel::construct(timeline);
-    int tid3 = TrackModel::construct(timeline);
     Q_UNUSED(tid3);
     int cid1 = CompositionModel::construct(timeline, aCompo, QString());
 
@@ -409,4 +440,5 @@ TEST_CASE("Composition manipulation", "[CompositionModel]")
         REQUIRE(timeline->requestItemResize(cid1, length - 2, true) > -1);
         REQUIRE(timeline->requestItemResize(cid2, length, false) > -1);
     }
+    pCore->projectItemModel()->clean();
 }
